@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,9 +28,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/clients/racluster.c#91 $
- * $DateTime: 2014/08/26 09:11:13 $
- * $Change: 2921 $
+ * $Id: //depot/argus/clients/clients/racluster.c#93 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -709,6 +709,7 @@ RaProcessThisRecord (struct ArgusParserStruct *parser, struct ArgusRecordStruct
             if (agg->labelstr)
                ArgusAddToRecordLabel(parser, ns, agg->labelstr);
 
+            if (agg->mask) {
             if ((agg->rap = RaFlowModelOverRides(agg, ns)) == NULL)
                agg->rap = agg->drap;
 
@@ -963,12 +964,15 @@ RaProcessThisRecord (struct ArgusParserStruct *parser, struct ArgusRecordStruct
                ArgusAddToQueue (agg->queue, &tns->qhdr, ARGUS_NOLOCK);
                agg->status |= ARGUS_AGGREGATOR_DIRTY;
             }
+            } else {
+               ArgusAddToQueue (agg->queue, &ns->qhdr, ARGUS_NOLOCK);
+               agg->status |= ARGUS_AGGREGATOR_DIRTY;
+            }
 
             if (agg->cont)
                agg = agg->nxt;
             else
                found++;
-
          } else
             agg = agg->nxt;
       }
