@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/clients/radium.c#12 $
- * $DateTime: 2014/02/13 18:39:51 $
- * $Change: 2754 $
+ * $Id: //depot/argus/clients/clients/radium.c#16 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 /*
@@ -398,6 +398,13 @@ usage ()
 }
 
 
+#define RADIUM_MAX_ANALYTICS	128
+struct ArgusRecordStruct *(*RadiumAnalyticAlgorithmTable[RADIUM_MAX_ANALYTICS])(struct ArgusParserStruct *, struct ArgusRecordStruct *) = {
+   NULL, NULL, NULL
+};
+
+
+
 void
 RaProcessRecord (struct ArgusParserStruct *parser, struct ArgusRecordStruct *argus)
 {
@@ -528,10 +535,18 @@ RaProcessRecord (struct ArgusParserStruct *parser, struct ArgusRecordStruct *arg
    }
 
    if ((ns = ArgusCopyRecordStruct(argus)) != NULL) {
-      if (parser->ArgusLabeler != NULL) 
-         ArgusLabelRecord(parser, ns);
+      int i;
+      for (i = 0; i < RADIUM_MAX_ANALYTICS; i++) {
+         if (RadiumAnalyticAlgorithmTable[i] != NULL) {
+            if ((ns = RadiumAnalyticAlgorithmTable[i](parser, ns)) == NULL)
+               break;
 
-      ArgusPushBackList(parser->ArgusOutput->ArgusOutputList, (struct ArgusListRecord *) ns, ARGUS_LOCK);
+         } else
+            break;
+      }
+
+      if (ns != NULL)
+         ArgusPushBackList(parser->ArgusOutput->ArgusOutputList, (struct ArgusListRecord *) ns, ARGUS_LOCK);
    }
 
 #if defined(ARGUS_THREADS)
@@ -821,6 +836,8 @@ RadiumParseResourceFile (struct ArgusParserStruct *parser, char *file)
 
                         case RADIUM_FILTER_TAG:
                            if ((parser->ArgusRemoteFilter = ArgusCalloc (1, MAXSTRLEN)) != NULL) {
+                              struct nff_program filter;
+
                               ptr = parser->ArgusRemoteFilter;
                               str = optarg;
                               while (*str) {
@@ -835,6 +852,9 @@ RadiumParseResourceFile (struct ArgusParserStruct *parser, char *file)
                                  else
                                     str++;
                               }
+
+                              if (ArgusFilterCompile (&filter, parser->ArgusRemoteFilter, 0) < 0)
+                                 ArgusLog (LOG_ERR, "RaParseResourceFile: remote filter syntax error");
 #ifdef ARGUSDEBUG
                               ArgusDebug (1, "RadiumParseResourceFile: ArgusFilter \"%s\" \n", parser->ArgusRemoteFilter);
 #endif 
@@ -923,6 +943,7 @@ RadiumParseResourceFile (struct ArgusParserStruct *parser, char *file)
                            if (RaLabelParseResourceFile (parser, parser->ArgusLabeler, optarg) != 0)
                               ArgusLog (LOG_ERR, "ArgusClientInit: label conf file error %s", strerror(errno));
 
+                           RadiumAnalyticAlgorithmTable[0] = ArgusLabelRecord;
                            break;
                         }
                      }
