@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,9 +30,9 @@
  */
 
 /* 
- * $Id: //depot/argus/clients/common/argus_parser.c#49 $
- * $DateTime: 2014/05/13 17:38:34 $
- * $Change: 2824 $
+ * $Id: //depot/argus/clients/common/argus_parser.c#53 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 
@@ -129,7 +129,8 @@ ArgusInitializeParser(struct ArgusParserStruct *parser)
    parser->ArgusTotalSrcBytes   = 0;
    parser->ArgusTotalDstBytes   = 0;
 
-   parser->RaLabelCounter      = 0;
+   parser->RaLabelCounter       = 0;
+   parser->RaFilterTimeout      = 1.5;
 
    if (parser->ArgusListens) {
       for (i = 0; i < parser->ArgusListens; i++)
@@ -317,7 +318,7 @@ ArgusCloseParser(struct ArgusParserStruct *parser)
 
    parser->debugflag = -1;
 
-   if (parser->ArgusProgramArgs != NULL);
+   if (parser->ArgusProgramArgs != NULL)
       ArgusFree(parser->ArgusProgramArgs);
 
 #if defined(ARGUSPERFMETRICS)
