@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,9 +32,9 @@
  */
 
 /*
- * $Id: //depot/argus/clients/examples/raconvert/raconvert.c#13 $
- * $DateTime: 2014/05/12 10:49:40 $
- * $Change: 2818 $
+ * $Id: //depot/argus/clients/examples/raconvert/raconvert.c#16 $
+ * $DateTime: 2016/06/01 15:17:28 $
+ * $Change: 3148 $
  */
 
 
@@ -97,6 +97,11 @@ unsigned int ArgusSourceId = 0;
 unsigned int ArgusIdType = 0;
 
 
+#define ARGUS_CONTINUE		0x100
+#define ARGUS_REQUEST		0x200
+#define ARGUS_RESPONSE		0x400
+#define ARGUS_INIT		0x800
+
 int
 main (int argc, char **argv)
 {
@@ -415,8 +420,10 @@ RaConvertParseTitleString (char *str)
             if (!(strncmp(RaParseLabelStringTable[i], obj, len))) {
                RaParseLabelAlgorithmIndex++;
                RaParseLabelAlgorithms[items] = RaParseLabelAlgorithmTable[i];
-               if (i == ARGUSPRINTDIR)   RaConvertParseDirLabel++;
-               if (i == ARGUSPRINTSTATE) RaConvertParseStateLabel++;
+               if (i == ARGUSPARSEDIRLABEL)
+                  RaConvertParseDirLabel++;
+               if (i == ARGUSPARSESTATELABEL)
+                  RaConvertParseStateLabel++;
                break;
             }
          }
@@ -434,6 +441,7 @@ RaConvertParseTitleString (char *str)
 
 int RaConvertParseRecordString (struct ArgusParserStruct *, char *);
 int ArgusParseDirStatus = -1;
+int ArgusParseTCPState = -1;
 int ArgusParseState = -1;
 int ArgusThisProto = -1;
 
@@ -465,11 +473,9 @@ RaConvertParseRecordString (struct ArgusParserStruct *parser, char *str)
    sprintf (delim, "%c", RaConvertDelimiter[0]);
    tptr = ptr;
 
-   for (ap = argv; (*ap = strtok(tptr, delim)) != NULL;) {
-      tptr = NULL;
+   for (ap = argv; (*ap = strsep(&tptr, delim)) != NULL;)
       if (++ap >= &argv[ARGUS_MAX_PRINT_FIELDS])
          break;
-   }
 
    numfields = ((char *)ap - (char *)argv)/sizeof(ap);
 
@@ -480,7 +486,7 @@ RaConvertParseRecordString (struct ArgusParserStruct *parser, char *str)
             switch (parser->argus.hdr.type) {
                case ARGUS_MAR:
                case ARGUS_EVENT:
-                  return(retn);
+                  return(0);
                   break;
             }
          }
@@ -489,26 +495,89 @@ RaConvertParseRecordString (struct ArgusParserStruct *parser, char *str)
 
    if (RaConvertParseDirLabel) {
       struct ArgusNetworkStruct *net = (struct ArgusNetworkStruct *) &parser->canon.net;
-      if (net) {
-         switch (net->hdr.subtype) {
-            case ARGUS_TCP_INIT:
-            case ARGUS_TCP_STATUS:
-            case ARGUS_TCP_PERF: {
-               struct ArgusTCPObject *tcp = (struct ArgusTCPObject *)&net->net_union.tcp;
-               tcp->status |= ArgusParseDirStatus;
-            }
+      switch (net->hdr.subtype) {
+         case ARGUS_TCP_INIT:
+         case ARGUS_TCP_STATUS:
+         case ARGUS_TCP_PERF: {
+            struct ArgusTCPObject *tcp = (struct ArgusTCPObject *)&net->net_union.tcp;
+            tcp->status |= ArgusParseDirStatus;
          }
       }
    }
    if (RaConvertParseStateLabel) {
-      struct ArgusNetworkStruct *net = (struct ArgusNetworkStruct *) &parser->canon.net;
-      if (net) {
-         switch (net->hdr.subtype) {
-            case ARGUS_TCP_INIT:
-            case ARGUS_TCP_STATUS:
-            case ARGUS_TCP_PERF: {
-               struct ArgusTCPObject *tcp = (struct ArgusTCPObject *)&net->net_union.tcp;
-               tcp->status |= ArgusParseState;
+      switch (parser->canon.flow.hdr.argus_dsrvl8.qual & 0x1F) {
+         case ARGUS_TYPE_IPV4: {
+            switch (parser->canon.flow.ip_flow.ip_p) {
+               case IPPROTO_TCP: {
+                  struct ArgusNetworkStruct *net = (struct ArgusNetworkStruct *) &parser->canon.net;
+                  switch (net->hdr.subtype) {
+                     case ARGUS_TCP_INIT:
+                     case ARGUS_TCP_STATUS:
+                     case ARGUS_TCP_PERF: {
+                        struct ArgusTCPObject *tcp = (struct ArgusTCPObject *)&net->net_union.tcp;
+                        tcp->status |= ArgusParseTCPState;
+                     }
+                  }
+                  break;
+               }
+               case IPPROTO_UDP: {
+                  switch (ArgusParseState) {
+                     case ARGUS_REQUEST:
+                     case ARGUS_CONTINUE:
+                     case ARGUS_RESPONSE:
+                        break;
+
+                     case ARGUS_INIT:
+                        parser->argus.hdr.cause |= ARGUS_START;
+                        break;
+                  }
+                  break;
+               }
+            }
+            break;
+         }
+         case ARGUS_TYPE_IPV6: {
+            switch (parser->canon.flow.ipv6_flow.ip_p) {
+               case IPPROTO_TCP: {
+                  struct ArgusNetworkStruct *net = (struct ArgusNetworkStruct *) &parser->canon.net;
+                  switch (net->hdr.subtype) {
+                     case ARGUS_TCP_INIT:
+                     case ARGUS_TCP_STATUS:
+                     case ARGUS_TCP_PERF: {
+                        struct ArgusTCPObject *tcp = (struct ArgusTCPObject *)&net->net_union.tcp;
+                        tcp->status |= ArgusParseTCPState;
+                     }
+                  }
+                  break;
+               }
+               case IPPROTO_UDP: {
+                  switch (ArgusParseState) {
+                     case ARGUS_REQUEST:
+                     case ARGUS_CONTINUE:
+                     case ARGUS_RESPONSE:
+                        break;
+
+                     case ARGUS_INIT:
+                        parser->argus.hdr.cause |= ARGUS_START;
+                        break;
+                  }
+                  break;
+               }
+            }
+            break;
+         }
+
+         case ARGUS_TYPE_RARP:
+         case ARGUS_TYPE_ARP: {
+            switch (ArgusParseState) {
+               case ARGUS_REQUEST:
+               case ARGUS_CONTINUE:
+               case ARGUS_RESPONSE:
+                  break;
+
+               case ARGUS_INIT:
+                  parser->argus.hdr.cause |= ARGUS_START;
+                  break;
             }
          }
       }
@@ -663,81 +732,81 @@ RaConvertReadFile (struct ArgusParserStruct *parser, struct ArgusInput *input)
                         }
                      }
 
-         } else {
-            if (!parser->qflag) {
-               static char buf[MAXSTRLEN];
-               int retn = 0, RaPrintCounter = 1;
+                  } else {
+                     if (!parser->qflag) {
+                        static char buf[MAXSTRLEN];
+                        int retn = 0, RaPrintCounter = 1;
 
-               if (parser->Lflag && !(parser->ArgusPrintXml)) {
-                  if (parser->RaLabel == NULL)
-                     parser->RaLabel = ArgusGenerateLabel(parser, argus);
-       
-                  if (!(parser->RaLabelCounter++ % parser->Lflag))
-                     if ((retn = printf ("%s\n", parser->RaLabel)) < 0) 
-                        RaParseComplete (SIGQUIT);
-       
-                  if (parser->Lflag < 0)
-                     parser->Lflag = 0;
-               }
-      
-               bzero (buf, sizeof(buf));
-               argus->rank = RaPrintCounter++;
+                        if (parser->Lflag && !(parser->ArgusPrintXml)) {
+                           if (parser->RaLabel == NULL)
+                              parser->RaLabel = ArgusGenerateLabel(parser, argus);
+                
+                           if (!(parser->RaLabelCounter++ % parser->Lflag))
+                              if ((retn = printf ("%s\n", parser->RaLabel)) < 0) 
+                                 RaParseComplete (SIGQUIT);
+                
+                           if (parser->Lflag < 0)
+                              parser->Lflag = 0;
+                        }
+               
+                        bzero (buf, sizeof(buf));
+                        argus->rank = RaPrintCounter++;
 
-               if ((ArgusParser->eNoflag == 0 ) || ((ArgusParser->eNoflag >= argus->rank) && (ArgusParser->sNoflag <= argus->rank))) {
-                  ArgusPrintRecord(parser, buf, argus, MAXSTRLEN);
-      
-                  if ((retn = fprintf (stdout, "%s", buf)) < 0)
-                     RaParseComplete (SIGQUIT);
-      
-                  if (parser->eflag == ARGUS_HEXDUMP) {
-                     int i;
-                     for (i = 0; i < MAX_PRINT_ALG_TYPES; i++) {
-                        if (parser->RaPrintAlgorithmList[i] != NULL) {
-                           struct ArgusDataStruct *user = NULL;
-                           if (parser->RaPrintAlgorithmList[i]->print == ArgusPrintSrcUserData) {
-                              int slen = 0, len = parser->RaPrintAlgorithmList[i]->length;
-                              if (len > 0) {
-                                 if ((user = (struct ArgusDataStruct *)argus->dsrs[ARGUS_SRCUSERDATA_INDEX]) != NULL) {
-                                    if (user->hdr.type == ARGUS_DATA_DSR) {
-                                       slen = (user->hdr.argus_dsrvl16.len - 2 ) * 4;
-                                    } else
-                                       slen = (user->hdr.argus_dsrvl8.len - 2 ) * 4;
-                                       
-                                    slen = (user->count < slen) ? user->count : slen;
-                                    slen = (slen > len) ? len : slen;
-                                    ArgusDump ((const u_char *) &user->array, slen, "      ");
-                                 }
+                        if ((ArgusParser->eNoflag == 0 ) || ((ArgusParser->eNoflag >= argus->rank) && (ArgusParser->sNoflag <= argus->rank))) {
+                           ArgusPrintRecord(parser, buf, argus, MAXSTRLEN);
+               
+                           if ((retn = fprintf (stdout, "%s", buf)) < 0)
+                              RaParseComplete (SIGQUIT);
+               
+                           if (parser->eflag == ARGUS_HEXDUMP) {
+                              int i;
+                              for (i = 0; i < MAX_PRINT_ALG_TYPES; i++) {
+                                 if (parser->RaPrintAlgorithmList[i] != NULL) {
+                                    struct ArgusDataStruct *user = NULL;
+                                    if (parser->RaPrintAlgorithmList[i]->print == ArgusPrintSrcUserData) {
+                                       int slen = 0, len = parser->RaPrintAlgorithmList[i]->length;
+                                       if (len > 0) {
+                                          if ((user = (struct ArgusDataStruct *)argus->dsrs[ARGUS_SRCUSERDATA_INDEX]) != NULL) {
+                                             if (user->hdr.type == ARGUS_DATA_DSR) {
+                                                slen = (user->hdr.argus_dsrvl16.len - 2 ) * 4;
+                                             } else
+                                                slen = (user->hdr.argus_dsrvl8.len - 2 ) * 4;
+                                                
+                                             slen = (user->count < slen) ? user->count : slen;
+                                             slen = (slen > len) ? len : slen;
+                                             ArgusDump ((const u_char *) &user->array, slen, "      ");
+                                          }
+                                       }
+                                    }
+                                    if (parser->RaPrintAlgorithmList[i]->print == ArgusPrintDstUserData) {
+                                       int slen = 0, len = parser->RaPrintAlgorithmList[i]->length;
+                                       if (len > 0) {
+                                          if ((user = (struct ArgusDataStruct *)argus->dsrs[ARGUS_DSTUSERDATA_INDEX]) != NULL) {
+                                             if (user->hdr.type == ARGUS_DATA_DSR) {
+                                                slen = (user->hdr.argus_dsrvl16.len - 2 ) * 4;
+                                             } else
+                                                slen = (user->hdr.argus_dsrvl8.len - 2 ) * 4;
+                  
+                                             slen = (user->count < slen) ? user->count : slen;
+                                             slen = (slen > len) ? len : slen;
+                                             ArgusDump ((const u_char *) &user->array, slen, "      ");
+                                          }
+                                       }
+                                    }
+                                 } else
+                                    break;
                               }
                            }
-                           if (parser->RaPrintAlgorithmList[i]->print == ArgusPrintDstUserData) {
-                              int slen = 0, len = parser->RaPrintAlgorithmList[i]->length;
-                              if (len > 0) {
-                                 if ((user = (struct ArgusDataStruct *)argus->dsrs[ARGUS_DSTUSERDATA_INDEX]) != NULL) {
-                                    if (user->hdr.type == ARGUS_DATA_DSR) {
-                                       slen = (user->hdr.argus_dsrvl16.len - 2 ) * 4;
-                                    } else
-                                       slen = (user->hdr.argus_dsrvl8.len - 2 ) * 4;
-         
-                                    slen = (user->count < slen) ? user->count : slen;
-                                    slen = (slen > len) ? len : slen;
-                                    ArgusDump ((const u_char *) &user->array, slen, "      ");
-                                 }
-                              }
-                           }
-                        } else
-                           break;
+                  
+                           fprintf (stdout, "\n");
+                           fflush (stdout);
+
+                        } else {
+                           if ((ArgusParser->eNoflag != 0 ) && (ArgusParser->eNoflag < argus->rank))
+                              RaParseComplete (SIGQUIT);
+                        }
                      }
                   }
-         
-                  fprintf (stdout, "\n");
-                  fflush (stdout);
-
-               } else {
-                  if ((ArgusParser->eNoflag != 0 ) && (ArgusParser->eNoflag < argus->rank))
-                     RaParseComplete (SIGQUIT);
-               }
-            }
-         }
                }
             }
          }
@@ -2151,26 +2220,91 @@ ArgusParseIdleJitterLabel (struct ArgusParserStruct *parser, char *buf)
 }
 
 
-
 void
 ArgusParseStateLabel (struct ArgusParserStruct *parser, char *buf)
 {
    int match = 0;
 
+   ArgusParseTCPState = 0;
    ArgusParseState = 0;
 
-   if (!(strcmp (buf, "REQ"))) {  ArgusParseState |= ARGUS_SAW_SYN; match++; }
-   if (!(strcmp (buf, "ACC"))) {  ArgusParseState |= ARGUS_SAW_SYN_SENT; match++; }
-   if (!(strcmp (buf, "CON"))) {  ArgusParseState |= ARGUS_CON_ESTABLISHED; match++; }
-   if (!(strcmp (buf, "TIM"))) {  ArgusParseState |= ARGUS_TIMEOUT; match++; }
-   if (!(strcmp (buf, "CLO"))) {  ArgusParseState |= ARGUS_NORMAL_CLOSE; match++; }
-   if (!(strcmp (buf, "FIN"))) {  ArgusParseState |= ARGUS_FIN; match++; }
-   if (!(strcmp (buf, "RST"))) {  ArgusParseState |= ARGUS_RESET; match++; }
+   if (!(strcmp (buf, "REQ"))) {  ArgusParseTCPState |= ARGUS_SAW_SYN;
+                                     ArgusParseState |= ARGUS_REQUEST; match++; }
+   if (!(strcmp (buf, "ACC"))) {  ArgusParseTCPState |= ARGUS_SAW_SYN_SENT; match++; }
+   if (!(strcmp (buf, "CON"))) {  ArgusParseTCPState |= ARGUS_CON_ESTABLISHED; match++; }
+   if (!(strcmp (buf, "TIM"))) {  ArgusParseTCPState |= ARGUS_TIMEOUT; match++; }
+   if (!(strcmp (buf, "CLO"))) {  ArgusParseTCPState |= ARGUS_NORMAL_CLOSE; match++; }
+   if (!(strcmp (buf, "FIN"))) {  ArgusParseTCPState |= ARGUS_FIN; match++; }
+   if (!(strcmp (buf, "RST"))) {  ArgusParseTCPState |= ARGUS_RESET; match++; }
+
+   if (!(strcmp (buf, "CON"))) {  ArgusParseState |= ARGUS_CONTINUE; match++; }
+   if (!(strcmp (buf, "RSP"))) {  ArgusParseState |= ARGUS_RESPONSE; match++; }
+   if (!(strcmp (buf, "INT"))) {  ArgusParseState |= ARGUS_INIT; match++; }
 
    if (!match) {
       int i;
       for (i = 0; i < ICMP_MAXTYPE; i++) {
-         if (!(strcmp (buf, icmptypestr[i]))) {
+         if (icmptypestr[i] != NULL) {
+            int len = strlen(icmptypestr[i]);
+            if ((len > 0) && !(strncmp (buf, icmptypestr[i], len))) {
+               switch (i) {
+                  default:
+                  case ICMP_MASKREPLY: 
+                  case ICMP_ECHOREPLY:  {
+                     parser->canon.flow.flow_un.icmp.type = i;
+                     parser->canon.flow.flow_un.icmp.code = 0;
+                     break;
+                  }
+                  case ICMP_UNREACH: 
+                     parser->canon.flow.flow_un.icmp.type = i;
+                     switch (buf[2]) {
+                        case 'O': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_PROTOCOL; break;
+                        case 'S': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_SRCFAIL; break;
+                        case 'I': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_ISOLATED; break;
+                        case 'C': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_PRECEDENCE_CUTOFF; break;
+                        case 'P': {
+                           switch(buf[3]) {
+                              case '\0': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_PORT; break;
+                              case  'R': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_HOST_PRECEDENCE; break;
+                           }
+                           break;
+                        }
+                        case 'F': {
+                           switch(buf[3]) { 
+                              case '\0': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_NEEDFRAG; break;
+                              case  'I': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_FILTER_PROHIB; break;
+                           }
+                           break;
+                        }
+                        case 'H': {
+                           switch(buf[3]) { 
+                              case '\0': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_HOST; break;
+                              case  'U': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_HOST_UNKNOWN; break;
+                              case  'P': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_HOST_PROHIB; break;
+                           }
+                           break;
+                        }
+                        case 'N': {
+                           switch(buf[3]) { 
+                              case '\0': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_NET; break;
+                              case  'U': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_NET_UNKNOWN; break;
+                              case  'P': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_NET_PROHIB; break;
+                              case  'T': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_TOSHOST; break;
+                           }
+                           break;
+                        }
+                     }
+                     break;
+
+                  case ICMP_REDIRECT:
+                     parser->canon.flow.flow_un.icmp.type = i;
+                     switch (buf[2]) {
+                        case 'O': parser->canon.flow.flow_un.icmp.code = ICMP_UNREACH_PROTOCOL; break;
+
+                     }
+                     break;
+               }
+            }
          }
       }
    }
