@@ -423,7 +423,7 @@ isakmp_sa_print(const struct isakmp_gen *ext,
 {
 	const struct isakmp_pl_sa *p;
 	struct isakmp_pl_sa sa;
-	const u_int32_t *q;
+//	const u_int32_t *q;
 	u_int32_t doi, sit, ident;
 	const u_char *cp, *np;
 	int t;
@@ -442,7 +442,7 @@ isakmp_sa_print(const struct isakmp_gen *ext,
 	}
 
 	sprintf(&ArgusBuf[strlen(ArgusBuf)]," doi=ipsec");
-	q = (u_int32_t *)&sa.sit;
+//	q = (u_int32_t *)&sa.sit;
 	sprintf(&ArgusBuf[strlen(ArgusBuf)]," situation=");
 	t = 0;
 	if (sit & 0x01) {
@@ -1351,7 +1351,7 @@ isakmp_print(const u_char *bp, u_int length)
 
 	if (ArgusParser->vflag) {
 		const struct isakmp_gen *ext;
-		int nparen;
+//		int nparen;
 
 #define CHECKLEN(p, np) \
 		if (ep < (u_char *)(p)) {				\
@@ -1371,7 +1371,7 @@ isakmp_print(const u_char *bp, u_int length)
 			goto done;
 		}
 
-		nparen = 0;
+//		nparen = 0;
 		CHECKLEN(p + 1, base.np)
 
 		np = base.np;
@@ -1392,9 +1392,10 @@ done:
 char *
 isakmp_rfc3948_print(const u_char *bp, u_int length)
 {
+/*
 	const u_char *ep;
 	ep = snapend;
-
+*/
 	if(length == 1 && bp[0]==0xff) {
 		sprintf(&ArgusBuf[strlen(ArgusBuf)],"isakmp-nat-keep-alive");
 		return ArgusBuf;
@@ -1415,20 +1416,22 @@ isakmp_rfc3948_print(const u_char *bp, u_int length)
 
 	/* must be an ESP packet */
 	{
-		int nh, enh, padlen;
-		int advance;
-
+/*
+  		int nh = 0, enh = 0, padlen = 0;
+		int advance = 0;
+*/
 		sprintf(&ArgusBuf[strlen(ArgusBuf)],"UDP-encap: ");
 /*
 		advance = esp_print(ndo, bp, length, bp2, &enh, &padlen);
-*/
-		if(advance <= 0)
+
+		if (advance <= 0)
 			return ArgusBuf;
 
 		bp += advance;
+
 		length -= advance + padlen;
 		nh = enh & 0xff;
-/*	     
+
 		ip_print_inner(ndo, bp, length, nh, bp2);
 */
 		return ArgusBuf;
