@@ -115,7 +115,8 @@ static void pimv2_print(register const u_char *bp, register u_int len);
 static void
 pimv1_join_prune_print(register const u_char *bp, register u_int len)
 {
-   int maddrlen, addrlen, ngroups, njoin, nprune, njp;
+// int maddrlen, addrlen, ngroups, njoin, nprune, njp;
+   int ngroups, njoin, nprune, njp;
    unsigned int haddr;
 
    /* If it's a single group and a single source, use 1-line output. */
@@ -154,8 +155,8 @@ pimv1_join_prune_print(register const u_char *bp, register u_int len)
    len -= 8;
 
    TCHECK2(bp[0], 4);
-   maddrlen = bp[1];
-   addrlen = bp[2];
+// maddrlen = bp[1];
+// addrlen = bp[2];
    ngroups = bp[3];
    bp += 4;
    len -= 4;
