@@ -413,8 +413,8 @@ char *
 rx_print(register const u_char *bp, int length, int sport, int dport)
 {
 	register struct rx_header *rxh;
+	int32_t opcode = 0;
 	int i;
-	int32_t opcode;
 
 	if (snapend - bp < (int)sizeof (struct rx_header)) {
 		sprintf(&ArgusBuf[strlen(ArgusBuf)]," [|rx] (%d)", length);
