@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2014 QoSient, LLC
+ * Copyright (c) 2000-2016 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -381,7 +381,6 @@ ArgusClientInit (struct ArgusParserStruct *parser)
 
          if (parser->ArgusFlowModelFile) {
             parser->ArgusAggregator = ArgusParseAggregator(parser, parser->ArgusFlowModelFile, NULL);
-               ArgusLog (LOG_ERR, "ArgusClientInit: ArgusParseAggregator error");
          } else
             parser->ArgusAggregator = ArgusNewAggregator(parser, NULL, ARGUS_RECORD_AGGREGATOR);
 
@@ -1132,6 +1131,7 @@ RaProcessThisRecord (struct ArgusParserStruct *parser, struct ArgusRecordStruct
             cns = ArgusCopyRecordStruct(ns);
             flow = (struct ArgusFlow *) cns->dsrs[ARGUS_FLOW_INDEX];
 
+            if (agg->mask) {
             if (flow != NULL) {
                if ((agg->rap = RaFlowModelOverRides(agg, cns)) == NULL)
                   agg->rap = agg->drap;
@@ -1192,6 +1192,7 @@ RaProcessThisRecord (struct ArgusParserStruct *parser, struct ArgusRecordStruct
                tagg = agg;
                agg = agg->nxt;
             }
+            }
             found++;
 
          } else
